@@ -70,10 +70,12 @@ static void conversions (void);
 static void formats (void);
 
 int init (void);
+#include "babl-verify-cpu.inc"
 
 int
 init (void)
 {
+  BABL_VERIFY_CPU();
   types ();
   components ();
   models ();
@@ -2974,6 +2976,20 @@ formats (void)
     babl_component ("CIE b"),
     NULL);
 
+  babl_format_new (
+    "name", "CIE Lab alpha u8",
+    babl_model ("CIE Lab alpha"),
+
+    babl_type ("CIE u8 L"),
+    babl_component ("CIE L"),
+    babl_type ("CIE u8 ab"),
+    babl_component ("CIE a"),
+    babl_type ("CIE u8 ab"),
+    babl_component ("CIE b"),
+    babl_type ("u8"),
+    babl_component ("A"),
+    NULL);
+
   babl_format_new (
     "name", "CIE Lab u16",
     babl_model ("CIE Lab"),
@@ -2986,6 +3002,20 @@ formats (void)
     babl_component ("CIE b"),
     NULL);
 
+  babl_format_new (
+    "name", "CIE Lab alpha u16",
+    babl_model ("CIE Lab alpha"),
+
+    babl_type ("CIE u16 L"),
+    babl_component ("CIE L"),
+    babl_type ("CIE u16 ab"),
+    babl_component ("CIE a"),
+    babl_type ("CIE u16 ab"),
+    babl_component ("CIE b"),
+    babl_type ("u16"),
+    babl_component ("A"),
+    NULL);
+
   babl_format_new (
     "name", "CIE xyY float",
     babl_model ("CIE xyY"),
